<template>
  <at-table
    @load="loadData"
    :data="data"
    :page-result="pageResult"
    ref="AtTable"
    :default-sorter="[
      {direction: 'DESC', property: 'project_code_'},
      {direction: 'DESC', property: 'project_name_'},
    ]"
    :dialogTitle="dialogTitle"
    :dialogVisible="dialogVisible"
    @select-all="handleSelect"
    @select="handleSelect"
    @handleDialogCancel="handleDialogCancel"
    @handleDialogClose="handleDialogClose"
    @handleDialogSubmit="handleDialogSubmit"
    @row-dblclick="handleRowDBClick"
  >
    <template v-slot:searchInput>
      <el-form
        ref="searchForm"
        :model="searchForm"
        label-width="80px"
        class="search-top"
        @submit.native.prevent
      >
        <project-info-selector
          v-if="isShow"
          v-model="searchForm.projectId"
          @keyup.enter.native="handleSearch"
        ></project-info-selector>
        <el-input
          v-model="searchForm.epidemicControlCode"
          placeholder="请输入编号/文号"
          @keyup.enter.native="handleSearch"
          clearable
        />
        <!-- <el-date-picker
          v-model="searchForm.establishmentDate"
          type="daterange"
          range-separator="-"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          @keyup.enter.native="handleSearch"
        >
        </el-date-picker> -->

        <el-date-picker
          v-model="searchForm.epidemicControlDate"
          type="date"
          placeholder="选择批复/检查日期"
          value-format="yyyy-MM-dd"
          format="yyyy-MM-dd"
          @keyup.enter.native="handleSearch"
        >
        </el-date-picker>
        <el-button
          size="small"
          @click="handleSearch"
          type="primary"
          class="el-icon-search search-btn"
          >查询</el-button
        >
        <el-button
          size="small"
          @click="handleReset"
          type="primary"
          plain
          class="el-icon-refresh"
          >重置</el-button
        >
      </el-form>
    </template>
    <template v-slot:operationBtn>
      <el-button
        size="small"
        type="primary"
        @click="handleAdd"
        icon="el-icon-plus"
        >添加</el-button
      >

      <ht-delete-button
        :url="deleteUrl"
        :htTable="$refs.AtTable"
        :requestMethod="'POST'"
        >删除</ht-delete-button
      >
      <import-file :importData="importData" @load="load"></import-file>
      <el-button
        size="small"
        type="primary"
        @click="handleExport"
        icon="el-icon-download"
        plain
        style="margin-left: 10px"
        >导出</el-button
      >
    </template>
    <template>
      <el-table-column type="selection" width="55" align="center">
      </el-table-column>
      <el-table-column type="index" label="序号" width="55" align="center">
      </el-table-column>
      <el-table-column
        prop="projectInfo.projectName"
        label="项目名称"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="epidemicControlCode"
        label="编号/文号"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="epidemicControlDate"
        label="批复/检查日期"
        min-width="100"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="epidemicControlUser"
        label="负责人"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="epidemicControlView"
        label="主要内容"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="remarks"
        label="备注"
        align="center"
        width="100"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
    </template>
    <!-- 弹框 -->
    <template v-slot:dialogContent>
      <el-form
        ref="ruleForm"
        data-vv-scope="form"
        :model="form"
        :rules="rules"
        label-width="130px"
        v-if="dialogVisible"
        v-form
      >
        <el-row>
          <el-col :span="12">
            <el-form-item label="项目名称" prop="projectInfo.projectName">
              <el-input
                v-model="form.projectInfo.projectName"
                placeholder="请选择项目名称"
                @focus="handleFocusProject"
                :disabled="!isShow"
                clearable
              >
                <el-button
                  type="primary"
                  @click="handleFocusProject"
                  slot="append"
                  icon="el-icon-search"
                ></el-button>
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
             <el-form-item label="编号/文号" prop="epidemicControlCode">
               <el-input
                v-model="form.epidemicControlCode"
                placeholder="请输入编号/文号"
                clearable
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="12">
          <el-form-item label="批复/检查日期" prop="epidemicControlDate">
              <el-date-picker
                v-model="form.epidemicControlDate"
                type="date"
                placeholder="请输批复/检查日期"
                class="basisType"
                value-format="yyyy-MM-dd"
                format="yyyy-MM-dd"
              />
            </el-form-item>
          </el-col>
          <el-col :span="12">
             <el-form-item label="负责人" prop="epidemicControlUser">
              <el-input
                v-model="form.epidemicControlUser"
                placeholder="请输入负责人"
                clearable
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="主要内容" prop="epidemicControlView">
          <el-input
            v-model="form.epidemicControlView"
            placeholder="请输入主要内容"
            type="textarea"
          ></el-input>
        </el-form-item>
        <!-- <el-form-item label="疫检结果" prop="progressDescription">
          <el-input
            type="textarea"
            v-model="form.progressDescription"
            placeholder="请输入疫检结果"
          ></el-input>
        </el-form-item> -->
        <el-form-item label="备注" prop="remarks">
          <el-input
            type="textarea"
            v-model="form.remarks"
            placeholder="请输入备注"
          ></el-input>
        </el-form-item>
        <file-table @handleFile="accessoryInfo" :file="form.accessoryInfo" :info='"上传文件"' />
      </el-form>
    </template>
    <project-info-dialog
      ref="project"
      :single="true"
      @select="handleSelectProject"
    ></project-info-dialog>
  </at-table>
</template>
<script>
import ProjectInfoDialog from '@/components/dialog/ProjectInfoDialog.vue'
import req from '@/request.js'
import utils from '@/utils.js'
export default {
  name: 'ConstructionOther',
  components: {
    ProjectInfoDialog,
  },
   props:{
    pid:{
       type: String,
      default:''
    },
    isShow:{
      type:Boolean,
      default:true
    }
  },
  data() {
    return {
      importData: {
        title: '其它文件导入',
        templateName: '其它文件模板.xls',
        downloadUrl: '/../fvue/static/excel/EpidemicPreventionControl.xlsx',
        importUrl:
          window.context.cqxy +
          '/biz/processManagement/progressManageEpidemicControl/v1/importExcelData',
          showProject:true,
        projectId: '',
      },
      projectObj: [], //获取的所有项目数组
      searchForm: {
        projectId: '',
        epidemicControlCode: '',
        epidemicControlDate: '',
      }, //顶部搜索参数
      data: [], //表格数据
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0,
      },
      form: {
        epidemicControlUser: '',
        accessoryInfo: [],
        projectInfo: {
          projectName: '',
          projectCode: '',
        },
      },
      dialogVisible: false,
      dialogTitle: '添加',
      //表单验证
      rules: {
        'projectInfo.projectName': {
          required: true,
          message: '项目名称不能为空',
          trigger: 'blur',
        },
        // 'projectInfo.projectCode': {
        //   required: true,
        //   message: '项目代码不能为空',
        //   trigger: 'blur',
        // },
        // epidemicControlDate: {
        //   required: true,
        //   message: '检查日期不能为空',
        //   trigger: 'blur',
        // },
        // epidemicControlUser: {
        //   required: true,
        //   message: '负责人不能为空',
        //   trigger: 'blur',
        // },
      },
    }
  },
  computed: {
    deleteUrl: function () {
      return (
        window.context.cqxy +
        '/biz/processManagement/progressManageEpidemicControl/v1/delete'
      )
    },
  },
  mounted() {
    this.initProjectAll()
  },
  methods: {
    //重置
    handleReset() {
      this.searchForm.projectId = ''
      this.searchForm.epidemicControlCode = ''
      this.searchForm.epidemicControlDate = ''
      this.$refs['searchForm'].resetFields()
       this.pageResult={
        page:1,
        pageSize:20,
        total:0
      }
      this.$nextTick(()=>{
        this.$refs.AtTable.load()
      })
    },
    handleSelectProject(data) {
      this.form.epidemicControlUser = data.projectManager
      this.form.projectInfo.projectName = data.projectName
      this.form.projectInfo.projectCode = data.projectCode
      this.form.projectId = data.id
      this.$refs.ruleForm.clearValidate()
    },
    //打开选择项目弹框
    handleFocusProject() {
      this.$refs.project.open()
    },
    //导入后重新加载数据
    load() {
      this.$refs.AtTable.load()
    },
    //导出
    handleExport() {
      let query = []
      let search = {
        'pm.ID_': this.searchForm.projectId,
        epidemic_control_code_: this.searchForm.epidemicControlCode,
        epidemic_control_date_: this.searchForm.epidemicControlDate,
      }
       if(!this.isShow){
       search['pm.ID_']=this.pid
      }
      for (let i in search) {
        if (search[i]) {
          query.push({
            group: 'advance',
            operation: 'LIKE',
            property: i,
            relation: 'AND',
            value: search[i],
          })
        }
      }
      let param = {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true,
        },

        querys: query,
        sorter: [],
      }
      req
        .downloadPostCopy(
          '${cqxy}/biz/processManagement/progressManageEpidemicControl/v1/exportDataToExcel',
          param
        )
        .then((res) => {
          if (res.status == 200) {
            this.$message.success('导出成功')
          } else {
            this.$message.error('导出失败')
          }
        })
    },
    //获取附件信息
    accessoryInfo(info) {
      this.form.accessoryInfo = info
    },
     initProjectAll() {
      //初始获取所有项目数据
      if(this.isShow){
        this.$http.post('${cqxy}/biz/projectManagement/pm/v1/All').then(
        (res) => {
          this.projectObj = res.data.value
        },
        (error) => {
          reject(error)
        }
      )
      }else{
        let params={
          pageBean:{
            page:1,
            pageSize:500,
            total:0
          },
          querys:[
            {
               group: 'main',
            operation: 'EQUAL',
            property: 'id',
            relation: 'AND',
            value: this.pid,
            }
          ]
        }
        this.$http.post('${cqxy}/biz/projectManagement/pm/v1/page',params).then(res=>{
          if(res.data.state){
            let resp=res.data.value
            this.projectObj=resp.rows
          }
        })
      }
    },
    //查询
    handleSearch() {
      this.$refs.AtTable.load()
    },
    afterSaveData() {
      setTimeout(() => {
        this.form = {
          epidemicControlUser: '',
          accessoryInfo: [],
          projectInfo: {
            projectName: '',
            projectCode: '',
          },
        }
        this.beforeCloseDialog()
        this.$refs.AtTable.load()
      }, 500)
    },
    beforeCloseDialog() {
      this.dialogVisible = false
    },
    handleAdd() {
      this.dialogTitle = '添加'
      this.dialogVisible = true
       if(this.isShow){
         let selectedProject = this.projectObj.find((item) => {
        if (item.currentProject && item.currentProject == 1) {
          return item.currentProject == 1
        }
      })
          // //获取当前时间
      let date = new Date()
      this.form.epidemicControlDate = utils.formatDateYear(date)
      this.form.projectInfo.projectName = selectedProject.projectName
      this.form.projectInfo.projectCode = selectedProject.projectCode
      this.form.epidemicControlUser = selectedProject.projectManager
      this.form.projectId = selectedProject.id
      }else{
        //根据项目id查询
         let date = new Date()
      this.form.epidemicControlDate = utils.formatDateYear(date)
      this.form.projectInfo.projectName = this.projectObj[0].projectName
      this.form.projectInfo.projectCode = this.projectObj[0].projectCode
      this.form.epidemicControlUser = this.projectObj[0].projectManager
      this.form.projectId = this.projectObj[0].id
      }
    },
    handleRowDBClick(data) {
      this.dialogTitle = '修改'
      this.$http
        .post(
          '${cqxy}/biz/processManagement/progressManageEpidemicControl/v1/detail/' +
            data.id
        )
        .then((res) => {
          this.dialogVisible = true
          let response = res.data.value
          this.form = response
        })
    },

    handleSelect(selection) {
    },
    handleDialogCancel() {
      this.dialogVisible = false
      this.form = {
        epidemicControlUser: '',
        accessoryInfo: [],
        projectInfo: {
          projectName: '',
          projectCode: '',
        },
      }
    },
    handleDialogClose() {
      this.dialogVisible = false
      this.form = {
        epidemicControlUser: '',
        accessoryInfo: [],
        projectInfo: {
          projectName: '',
          projectCode: '',
        },
      }
    },
    //提交保存
    handleDialogSubmit(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid && this.form.accessoryInfo.length !== 0) {
          this.form.accessoryInfo.forEach((item) => {
            if (item.id) {
              delete item.id
            }
          })
          this.$http
            .post(
              '${cqxy}/biz/processManagement/progressManageEpidemicControl/v1/save',
              this.form
            )
            .then((res) => {
              if (res.status == 200) {
                setTimeout(() => {
                  this.$message.success(res.data.message)
                  this.afterSaveData()
                }, 500)
              } else {
                this.$message.error(res.data.message)
              }
            })
        } else if (this.form.accessoryInfo.length === 0) {
          this.$message.error('至少上传一个附件')
        } else {
          this.$message({
            message: '*号必填项,不能为空!',
            type: 'warning',
          })
          return false
        }
      })
    },
    loadData(param, cb) {
       let query = []
      let search = {
       'pm.ID_': this.searchForm.projectId,
        epidemic_control_code_: this.searchForm.epidemicControlCode,
        epidemic_control_date_: this.searchForm.epidemicControlDate,
      }
      if(!this.isShow){
        search['pm.ID_']=this.pid
         this.importData.projectId=this.pid
      }
      for (let i in search) {
        if (search[i]) {
          query.push({
            group: 'advance',
            operation: 'LIKE',
            property: i,
            relation: 'AND',
            value: search[i],
          })
        }
      }
      if(param.querys && param.querys.length){
        param.querys.push(...query)
      }else{
        param.querys=query
      }

      this.$http
        .post(
          '${cqxy}/biz/processManagement/progressManageEpidemicControl/v1/page',
          param
        )
        .then(
          (resp) => {
            let response = resp.data.value
            this.data = response.rows
            this.pageResult = {
              page: response.page,
              pageSize: response.pageSize,
              total: response.total,
            }
          },
          (error) => {
            reject(error)
          }
        )
        .finally(() => cb())
    },
  },
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/common.scss';
</style>
